<?php

// Setup CRON for automated processing
add_action( 'sunshine_install', 'sunshine_register_ftp_image_update', 99 );
add_action( 'sunshine_update', 'sunshine_register_ftp_image_update', 99 );
function sunshine_register_ftp_image_update() {
	if ( ! wp_next_scheduled( 'sunshine_ftp_image_update' ) ) {
		wp_schedule_event( current_time( 'timestamp' ), 'daily', 'sunshine_ftp_image_update' );
	}
}

add_action( 'sunshine_deactivation', 'sunshine_unregister_ftp_image_update' );
function sunshine_unregister_ftp_image_update() {
	wp_clear_scheduled_hook( 'sunshine_ftp_image_update' );
}

add_action( 'sunshine_ftp_image_update', 'sunshine_ftp_image_update_process' );
function sunshine_ftp_image_update_process() {

	// Get all galleries that are set to use FTP folder
	$args      = array(
		'post_type'  => 'sunshine-gallery',
		'nopaging'   => true,
		'meta_query' => array(
			array(
				'key'     => 'sunshine_gallery_images_directory',
				'value'   => '',
				'compare' => '!=',
			),
		),
	);
	$galleries = get_posts( $args );
	foreach ( $galleries as $_gallery ) {

		$gallery = new WPSunshine_Gallery( $_gallery );

		$existing_file_names = array();
		$existing_images     = get_children(
			array(
				'post_parent'    => $gallery->get_id(),
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
			)
		);
		foreach ( $existing_images as $existing_image ) {
			$file_name = get_post_meta( $existing_image->ID, 'sunshine_file_name', true );
			if ( $file_name ) {
				$existing_file_names[] = $file_name;
			}
		}

		// Get image counts for each gallery and compare to image count in the folder
		$gallery_folder = $gallery->get_image_directory();
		if ( empty( $gallery_folder ) ) {
			continue;
		}
		$upload_dir    = wp_upload_dir();
		$folder        = $upload_dir['basedir'] . '/sunshine/' . $gallery_folder;
		$images        = sunshine_get_images_in_folder( $folder );
		$import_images = array();
		foreach ( $images as $image ) {
			if ( ! in_array( basename( $image ), $existing_file_names ) ) {
				$import_images[] = $image;
			}
		}

		// Import any new images we find
		if ( ! empty( $import_images ) ) {

			include_once ABSPATH . 'wp-admin/includes/image.php';

			foreach ( $import_images as $file_path ) {

				$file_name = basename( $file_path );

				// Import this file

				$wp_filetype = wp_check_filetype( $file_name, null );
				extract( $wp_filetype );

				$new_file_name = wp_unique_filename( $upload_dir['path'], $file_name );

				// copy the file to the uploads dir
				$new_file_path = $upload_dir['path'] . '/' . $new_file_name;
				if ( false === @copy( $file_path, $new_file_path ) ) {
					continue;
				}

				// Set correct file permissions
				$stat  = stat( dirname( $new_file_path ) );
				$perms = $stat['mode'] & 0000666;
				@chmod( $new_file, $perms );
				$url = $upload_dir['url'] . '/' . $new_file_name;

				// Apply upload filters
				$return   = apply_filters(
					'wp_handle_upload',
					array(
						'file' => $new_file_path,
						'url'  => $url,
						'type' => $type,
					)
				);
				$new_file = $return['file'];
				$url      = $return['url'];
				$type     = $return['type'];

				$title   = preg_replace( '!\.[^.]+$!', '', basename( $file_name ) );
				$content = '';

				// use image exif/iptc data for title and caption defaults if possible
				$image_meta = @wp_read_image_metadata( $new_file );
				if ( $image_meta ) {
					if ( '' != trim( $image_meta['title'] ) ) {
						$title = trim( $image_meta['title'] );
					}
					if ( '' != trim( $image_meta['caption'] ) ) {
						$content = trim( $image_meta['caption'] );
					}
				}

				$post_date     = current_time( 'mysql' );
				$post_date_gmt = current_time( 'mysql', 1 );

				// Construct the attachment array
				$attachment = array(
					'post_mime_type' => $type,
					'guid'           => $url,
					'post_parent'    => $gallery->get_id(),
					'post_title'     => $title,
					'post_name'      => $title,
					'post_content'   => $content,
					'post_date'      => $post_date,
					'post_date_gmt'  => $post_date_gmt,
				);

				$new_file = str_replace( wp_normalize_path( $upload_dir['basedir'] ), $upload_dir['basedir'], $new_file );

				// Save the data
				$attachment_id = wp_insert_attachment( $attachment, $new_file, $gallery->get_id() );
				if ( ! is_wp_error( $attachment_id ) ) {
					$data              = wp_generate_attachment_metadata( $attachment_id, $new_file );
					$created_timestamp = current_time( 'timestamp' );
					if ( ! empty( $image_meta['created_timestamp'] ) ) {
						$created_timestamp = $image_meta['created_timestamp'];
					}
					add_post_meta( $attachment_id, 'created_timestamp', $created_timestamp );
					add_post_meta( $attachment_id, 'sunshine_file_name', $file_name );

					do_action( 'sunshine_after_image_process', $attachment_id );
					$data = wp_update_attachment_metadata( $attachment_id, $data );
				}
			}
		}
	}

}
