<?php

add_action( 'admin_menu', 'sunshine_tracking_page' );
function sunshine_tracking_page() {
	add_submenu_page(
		'options.php',
		__( 'Sunshine Data Tracking', 'sunshine' ),
		__( 'Sunshine Data Tracking', 'sunshine' ),
		'manage_options',
		'sunshine_tracking_request',
		'sunshine_tracking_request'
	);
}

add_action( 'admin_init', 'sunshine_tracking_redirect' );
function sunshine_tracking_redirect() {
	if ( isset( $_GET['page'] ) && $_GET['page'] == 'sunshine_tracking_request' ) {
		return;
	}

	$tracking_status = get_option( 'sunshine_tracking' );
	if ( empty( $tracking_status ) ) {
		wp_redirect( admin_url( 'options.php?page=sunshine_tracking_request' ) );
		exit;
	}
}

add_action( 'sunshine_tracking_request', 'sunshine_tracking_request' );
function sunshine_tracking_request() {
?>
	<div class="wrap">
		<form method="post" action="options.php?page=sunshine_tracking_request">
			<?php wp_nonce_field( 'sunshine_tracking_request', 'sunshine_tracking_request' ); ?>
			<h1>Sunshine Photo Cart Data Tracking Request</h1>
			<p style="font-size: 18px;">Data tracking is being requested to help improve features for the upcoming Sunshine Photo Cart 3. <strong>This is completely optional!</strong></p>
			<p style="font-size: 18px;">If you agree, the following information will be sent to and stored on sunshinephotocart.com solely for research purposes and will not be sold or given to any 3rd party:</p>
			<ul style="list-style: none; margin-left: 25px;">
				<li><label><input type="checkbox" name="tracking[]" value="country" checked />Your country</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="order_count" checked />Total number of orders</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="order_total" checked />Total amount in sales</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="product_count" checked />Number of products</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="gallery_count" checked />Number of galleries</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="image_count" checked />Number of photos in galleries</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="install_date" checked />When you first installed Sunshine Photo Cart</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="payment_gateways" checked />Which payment gateways you have enabled</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="shipping" checked />Which shipping methods you have enabled</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="theme" checked />Your WordPress theme</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="sunshine_theme" checked />Sunshine theme</label></li>
			</ul>
			<p><strong>No image files or their metadata will be sent or stored in any way</strong></p>
			<p style="font-size: 18px;">The following is additional personally identifiable information you can optionally include to help provide further research:</p>
			<ul style="margin-left: 25px;">
				<li><label><input type="checkbox" name="tracking[]" value="website" /> Website URL (I would like to personally review sites to see how Sunshine is being used and either be included in the <a href="https://www.sunshinephotocart.com/examples/" target="_blank">Example Websites directory</a> or provide suggestions)</label></li>
				<li><label><input type="checkbox" name="tracking[]" value="email" /> Admin Email - <?php echo bloginfo( 'admin_email' ); ?> (To communicate with you regarding your website if needed)</label></li>
			</ul>
			<p style="margin-top: 40px;">
				<input type="submit" class="button button-primary" value="I agree to allow this information to be collected" /> 
				&nbsp; &nbsp; <a href="<?php echo admin_url( 'options.php?page=sunshine_tracking_request&deny=1' ); ?>" class="button">I do not agree, don't ask me again</a>
			</p>
		</form>
	</div>
<?php
}

add_action( 'admin_init', 'sunshine_tracking_request_save' );
function sunshine_tracking_request_save() {

	if ( isset( $_GET['page'] ) && $_GET['page'] == 'sunshine_tracking_request' && isset( $_GET['deny'] ) ) {
		update_option( 'sunshine_tracking', 'deny', false );
		wp_redirect( admin_url() );
		exit;
	}

	if ( ! isset( $_POST['sunshine_tracking_request'] ) || ! wp_verify_nonce( $_POST['sunshine_tracking_request'], 'sunshine_tracking_request' ) ) {
		return;
	}

	$tracking = array_map( 'sanitize_text_field', $_POST['tracking'] );
	update_option( 'sunshine_tracking', $tracking, false );

	// Set up monthly cron
	if ( ! wp_next_scheduled( 'sunshine_tracking' )) {
    	$result = wp_schedule_event( time(), 'weekly', 'sunshine_tracking' );
    }

	sunshine_tracking_send();

	wp_redirect( admin_url() );
	exit;

}

add_action( 'sunshine_deactivation', 'sunshine_unregister_tracking_cron' );
function sunshine_unregister_tracking_cron() {
	wp_clear_scheduled_hook( 'sunshine_tracking_send' );
}

/*
add_action( 'admin_notices', function() {
	if ( isset( $_GET['sunshine_tracking_send'] ) ) {
		sunshine_tracking_send();
	}
});
*/

add_action( 'sunshine_tracking', 'sunshine_tracking_send' );
function sunshine_tracking_send() {
	global $wpdb, $sunshine;

	$tracking_options = get_option( 'sunshine_tracking' );
	if ( empty( $tracking_options ) || $tracking_options == 'deny' ) {
		return;
	}

	$options = get_option( 'sunshine_options' );

	$data = array(
		'key' => md5( get_bloginfo( 'url' ) ),
		'country' => ( in_array( 'country', $tracking_options ) ) ? $options['country'] : '',
		'gallery_count' => ( in_array( 'gallery_count', $tracking_options ) ) ? wp_count_posts( 'sunshine-gallery' )->publish : '',
		'product_count' => ( in_array( 'product_count', $tracking_options ) ) ? wp_count_posts( 'sunshine-product' )->publish : '',
		'install_date' => ( in_array( 'install_date', $tracking_options ) ) ? get_option( 'sunshine_install_time' ) : '',
		'theme' => ( in_array( 'theme', $tracking_options ) ) ? wp_get_theme()->get( 'Name' ) : '',
		'sunshine_theme' => ( in_array( 'sunshine_theme', $tracking_options ) ) ? $options['theme'] : '',
		'website' => ( in_array( 'website', $tracking_options ) ) ? get_bloginfo( 'url' ) : '',
		'email' => ( in_array( 'email', $tracking_options ) ) ? get_bloginfo( 'admin_email' ) : '',
		'pro' => ( $sunshine->is_pro() ) ? 1 : 0,
	);

	// Order totals
	$args = array(
		'post_type' => 'sunshine-order',
		'nopaging' => true,
		'tax_query' => array(
			array(
				'taxonomy' => 'sunshine-order-status',
				'field'    => 'slug',
				'terms'    => array( 'new', 'processing', 'shipped', 'pickup' ),
			)
		)
	);
	$orders = get_posts( $args );
	$total = 0;
	$completed_sales = 0;
	if ( is_array( $orders ) ) {
		foreach ( $orders as $order ) {
			$order_data = maybe_unserialize( get_post_meta( $order->ID, '_sunshine_order_data', true ) );
			$total += $order_data['total'];
			$completed_sales++;
		}
	}

	$data['order_count'] = $completed_sales;
	$data['order_total'] = $total;

	$result = $wpdb->get_var(
		"SELECT COUNT(*) FROM wp_posts p 
		INNER JOIN wp_postmeta pm ON p.ID = pm.post_id 
		WHERE p.post_type = 'attachment' 
		AND pm.meta_key = 'sunshine_file_name'"
	);
	$data['image_count'] = $result;

	$payment_gateways = array();
	if ( ! empty( $options['paypal_active'] ) ) {
		$payment_gateways[] = 'paypal';
	}
	if ( ! empty( $options['offline_active'] ) ) {
		$payment_gateways[] = 'offline';
	}
	if ( ! empty( $options['stripe_active'] ) ) {
		$payment_gateways[] = 'stripe';
	}
	if ( ! empty( $options['authorizenet_active'] ) ) {
		$payment_gateways[] = 'authorizenet';
	}
	if ( ! empty( $options['payjunction_active'] ) ) {
		$payment_gateways[] = 'payjunction';
	}
	if ( ! empty( $options['mollie_active'] ) ) {
		$payment_gateways[] = 'mollie';
	}
	if ( ! empty( $options['square_active'] ) ) {
		$payment_gateways[] = 'square';
	}
	$data['payment_gateways'] = $payment_gateways;

	$shipping = array();
	if ( ! empty( $options['pickup_active'] ) ) {
		$shipping[] = 'pickup';
	}
	if ( ! empty( $options['local_active'] ) ) {
		$shipping[] = 'local';
	}
	if ( ! empty( $options['flat_rate_active'] ) ) {
		$shipping[] = 'flat_rate';
	}
	$data['shipping'] = $shipping;

	$data['action'] = 'tracking';

	$response = wp_remote_post(
		trailingslashit( SUNSHINE_STORE_URL ),
		array(
			'timeout'   => 100,
			'sslverify' => true,
			'body'      => $data,
		)
	);

}