<?php
add_action( 'personal_options_update', 'sunshine_admin_user_credits_process' );
add_action( 'edit_user_profile_update', 'sunshine_admin_user_credits_process' );
function sunshine_admin_user_credits_process( $user_id ) {
	if ( current_user_can( 'sunshine_manage_options' ) ) {
		SunshineUser::update_user_meta_by_id( $user_id, 'credits', sanitize_text_field( $_POST['sunshine_credits'] ) );
	}
}

add_action( 'show_user_profile', 'sunshine_admin_user_cart' );
add_action( 'edit_user_profile', 'sunshine_admin_user_cart' );
function sunshine_admin_user_cart( $user ) {
	if ( current_user_can( 'sunshine_manage_options' ) ) {
		$items  = SunshineUser::get_user_meta_by_id( $user->ID, 'cart', false );
		$orders = get_posts( 'post_type=sunshine-order&meta_key=_sunshine_customer_id&meta_value=' . $user->ID . '&nopaging=1' );
		?>
		<h3><?php _e( 'Orders', 'sunshine' ); ?></h3>
		<?php
		if ( $orders ) {
			echo '<ul>';
			foreach ( $orders as $order ) {
				$order_data = maybe_unserialize( get_post_meta( $order->ID, '_sunshine_order_data', true ) );
				$total      = sunshine_money_format( $order_data['total'], false );
				echo '<li><a href="post.php?post=' . esc_attr( $order->ID ) . '&action=edit">' . esc_html( $order->post_title ) . '</a>, ' . esc_html( gmdate( get_option( 'date_format' ), strtotime( $order->post_date ) ) ) . ' &mdash; ' . esc_html( $total ) . '</li>';
			}
		} else {
			echo '<li><em>' . __( 'User has no orders yet', 'sunshine' ) . '</em></li>';
		}
		?>
		<h3><?php _e( 'Address Information', 'sunshine' ); ?></h3>
		<table class="form-table">
		<tr>
			<th><?php _e( 'Billing Information', 'sunshine' ); ?></th>
			<td>
				<?php
				$address  = SunshineUser::get_user_meta_by_id( $user->ID, 'address' );
				$address2 = SunshineUser::get_user_meta_by_id( $user->ID, 'address2' );
				$city     = SunshineUser::get_user_meta_by_id( $user->ID, 'city' );
				$state    = SunshineUser::get_user_meta_by_id( $user->ID, 'state' );
				$zip      = SunshineUser::get_user_meta_by_id( $user->ID, 'zip' );
				$country  = SunshineUser::get_user_meta_by_id( $user->ID, 'country' );
				if ( $address ) {
					echo esc_html( $address ) . '<br />';
					if ( $address2 ) {
						echo esc_html( $address2 ) . '<br />';
					}
					echo esc_html( $city ) . ', ' . esc_html( $state ) . ' ' . esc_html( $zip ) . '<br />' . esc_html( $country );
				} else {
					echo '<em>' . __( 'No current billing address', 'sunshine' ) . '</em>';
				}
				?>
			</td>
		</tr>
		<tr>
			<th><?php _e( 'Shipping Information', 'sunshine' ); ?></th>
			<td>
				<?php
				$address  = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_address' );
				$address2 = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_address2' );
				$city     = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_city' );
				$state    = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_state' );
				$zip      = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_zip' );
				$country  = SunshineUser::get_user_meta_by_id( $user->ID, 'shipping_country' );
				if ( $address ) {
					echo esc_html( $address ) . '<br />';
					if ( $address2 ) {
						echo esc_html( $address2 ) . '<br />';
					}
					echo esc_html( $city ) . ', ' . esc_html( $state ) . ' ' . esc_html( $zip ) . '<br />' . esc_html( $country );
				} else {
					echo '<em>' . __( 'No current shipping address', 'sunshine' ) . '</em>';
				}
				?>
			</td>
		</tr>
		</table>

		<?php
		$args          = array(
			'post_type'  => 'sunshine-gallery',
			'meta_query' => array(
				array(
					'key'   => 'sunshine_gallery_private_user',
					'value' => $user->ID,
				),
			),
		);
		$gallery_query = new WP_Query( $args );
		if ( $gallery_query->have_posts() ) {
			?>
		<h3 id="sunshine-galleries"><?php _e( 'Assigned Galleries', 'sunshine' ); ?></h3>
		<ul>
			<?php
			while ( $gallery_query->have_posts() ) :
				$gallery_query->the_post();
				?>
				<li><a href="<?php echo admin_url( 'post.php?action=edit&post=' . get_the_ID() ); ?>"><?php the_title(); ?></a></li>
				<?php
			endwhile;
			wp_reset_postdata();
			?>
		</ul>
		<?php } ?>

		<h3 id="sunshine-credits"><?php _e( 'Gallery Credits for Purchases', 'sunshine' ); ?></h3>
		<table class="form-table">
		<tr>
			<th><label for="sunshine_credits"><?php _e( 'Credits', 'sunshine' ); ?></label></th>
			<td>
				<?php
				$currency_symbol        = sunshine_currency_symbol();
				$currency_symbol_format = sunshine_currency_symbol_format();
				$text_field_safe        = '<input type="text" name="sunshine_credits" id="sunshine_credits" value="' . esc_attr( SunshineUser::get_user_meta_by_id( $user->ID, 'credits' ) ) . '" />';
				echo sprintf( esc_attr( $currency_symbol_format ), esc_attr( $currency_symbol ), $text_field_safe );
				?>
			</td>
		</tr>
		</table>
		<h3 id="sunshine-cart"><?php _e( 'Items in Cart', 'sunshine' ); ?></h3>
		<?php if ( $items ) { ?>
			<table id="sunshine-cart-items" width="100%">
			<tr>
				<th class="image"><?php _e( 'Image', 'sunshine' ); ?></th>
				<th class="name"><?php _e( 'Product', 'sunshine' ); ?></th>
				<th class="qty"><?php _e( 'Quantity', 'sunshine' ); ?></th>
				<th class="price"><?php _e( 'Item Price', 'sunshine' ); ?></th>
			</tr>
			<?php foreach ( $items as $item ) { ?>
				<tr class="item">
					<td class="image">
						<?php
						$thumb      = wp_get_attachment_image_src( $item['image_id'], 'thumbnail' );
						$image_html = '<a href="' . get_permalink( $item['image_id'] ) . '"><img src="' . $thumb[0] . '" alt="" class="image-thumb" /></a>';
						echo wp_kses_post( apply_filters( 'sunshine_cart_image_html', $image_html, $item, $thumb ) );
						?>
					</td>
					<td class="name">
						<?php
						$product = get_post( $item['product_id'] );
						$cat     = wp_get_post_terms( $item['product_id'], 'sunshine-product-category' );
						?>
						<strong><span class="sunshine-item-cat"><?php echo esc_html( apply_filters( 'sunshine_cart_item_category', ( isset( $cat[0]->name ) ) ? $cat[0]->name : '', $item ) ); ?></span> - <span class="sunshine-item-name"><?php echo esc_html( apply_filters( 'sunshine_cart_item_name', $product->post_title, $item ) ); ?></span></strong><br />
						<div class="sunshine-item-comments"><?php echo wp_kses_post( apply_filters( 'sunshine_cart_item_comments', $item['comments'], $item ) ); ?></div>
					</td>
					<td class="qty">
						<?php echo esc_html( $item['qty'] ); ?>
					</td>
					<td class="price">
						<?php sunshine_money_format( $item['price'] ); ?>
					</td>
				</tr>
			<?php } ?>
			</table>
		<?php } else { ?>
			<p><?php _e( 'No items in cart', 'sunshine' ); ?></p>
		<?php } ?>
	<?php }
}


/**
 * Add duplicate link to action list for post_row_actions
 */
add_filter( 'user_row_actions', 'sunshine_user_link_row', 10, 2 );
function sunshine_user_link_row( $actions, $user ) {
	if ( current_user_can( 'sunshine_manage_options', $user->ID ) ) {
		$actions['sunshine_credits'] = '<a href="user-edit.php?user_id=' . $user->ID . '#sunshine-credits">' . __( 'Credits', 'sunshine' ) . '</a>';
	}
	return $actions;
}

?>
