<?php
class SunshineSession extends SunshineSingleton {

	private static $hash;
	private static $data;
	private static $option_key;

	protected function __construct() {
		if ( isset( $_COOKIE['sunshine_session'] ) ) {
			self::$hash = $_COOKIE['sunshine_session'];
		} else {
			self::$hash = md5( $_SERVER['REMOTE_ADDR'] . current_time( 'timestamp' ) );
			sunshine_setcookie( 'sunshine_session', self::$hash );
		}
		self::$option_key = 'sunshine_session_' . self::$hash . '_' . date( 'Ymd' );
		self::$data       = get_option( self::$option_key );
	}

	public function __get( $key ) {
		if ( ! empty( self::$data[ $key ] ) ) {
			return self::$data[ $key ];
		}

		return null;
	}

	public function __set( $key, $value ) {
		self::$data[ $key ] = $value;
		update_option( self::$option_key, self::$data, false );
		return $value;
	}

	public function __isset( $key ) {
		return isset( self::$data[ $key ] );
	}

	public function __unset( $key ) {
		unset( self::$data[ $key ] );
		update_option( self::$option_key, self::$data, false );
	}

}

/**
 * Original source: WooCommerce
 *
 * Set a cookie - wrapper for setcookie using WP constants
 *
 * @param  string  $name   Name of the cookie being set
 * @param  string  $value  Value of the cookie
 * @param  integer $expire Expiry of the cookie
 * @param  string  $secure Whether the cookie should be served only over https
 */

function sunshine_setcookie( $name, $value, $expire = 0, $secure = false, $from = '' ) {
	if ( ! headers_sent() ) {
		setcookie( $name, $value, $expire, COOKIEPATH, COOKIE_DOMAIN, $secure );
	} elseif ( defined( 'WP_DEBUG' ) && WP_DEBUG ) {
		headers_sent( $file, $line );
		// trigger_error( "{$name} cookie cannot be set - headers already sent by {$file} on line {$line}", E_USER_NOTICE );
	}
}

/**
 * Clean up expired sessions by removing data and their expiration entries from
 * the WordPress options table.
 *
 * This method should never be called directly and should instead be triggered as part
 * of a scheduled task or cron job.
 */
add_action( 'sunshine_session_garbage_collection', 'sunshine_session_cleanup' );
function sunshine_session_cleanup() {
	global $wpdb;
	// Delete session data for 30-45 days ago just in case some have slipped through from missed cron jobs
	for ( $i = 30; $i <= 45; $i++ ) {
		$date            = date( 'Ymd', strtotime( '-' . $i . ' days' ) );
		$expiration_keys = $wpdb->query( "DELETE FROM $wpdb->options WHERE option_name LIKE 'sunshine_session_%_$date'" );
	}
}

/**
 * Register the garbage collector as a daily event.
 */
add_action( 'sunshine_install', 'sunshine_session_register_garbage_collection', 99 );
add_action( 'sunshine_update', 'sunshine_session_register_garbage_collection', 99 );
function sunshine_session_register_garbage_collection() {
	if ( ! wp_next_scheduled( 'sunshine_session_garbage_collection' ) ) {
		wp_schedule_event( current_time( 'timestamp' ), 'daily', 'sunshine_session_garbage_collection' );
	}
}

add_action( 'sunshine_deactivation', 'sunshine_session_unregister_garbage_collection' );
function sunshine_session_unregister_garbage_collection() {
	wp_clear_scheduled_hook( 'sunshine_session_garbage_collection' );
}
